enum FlagStatus {
Unknown,
Candidate {
dropped_places: Vec<Place>,
},
Discarded,
}Variants
Unknown
We have tot encountered a switch on this boolean yet.
Candidate
This boolean has only been assigned constants and switched on, hence is a candidate drop flag. The places are these that were unconditionally dropped in every true branch of a switch on this flag.
Discarded
This boolean was used in a way that drop flags aren’t used.