GatherCandidates

Struct GatherCandidates 

struct GatherCandidates<'a> {
    body: &'a ExprBody,
    flag_statuses: IndexVec<LocalId, FlagStatus>,
}

Fields

body: &'a ExprBodyflag_statuses: IndexVec<LocalId, FlagStatus>

Implementations

Source

impl GatherCandidates<'_>

fn dropped_places_in_true_branch( &self, true_target: BlockId, false_target: BlockId, ) -> Vec<Place>

Follow the true branch until it reaches the false target, and accumulate any place that gets unconditionally dropped along the way. We ignore unwind paths and other switches.